@@ -9,7 +9,8 @@ import warnings
 import nbformat
 from dagster_graphql.implementation.context import (
     DagsterGraphQLContext,
-    DagsterSnapshotGraphQLContext,
+    DagsterGraphQLInProcessRepositoryContext,
+    DagsterGraphQLOutOfProcessRepositoryContext,
 )
 from dagster_graphql.implementation.pipeline_execution_manager import (
     QueueingSubprocessExecutionManager,
@@ -30,7 +31,7 @@ from dagster import __version__ as dagster_version
 from dagster import check, seven
 from dagster.core.execution.compute_logs import warn_if_compute_logs_disabled
 from dagster.core.instance import DagsterInstance
-from dagster.core.snap.repository_snapshot import RepositorySnapshot
+from dagster.core.snap import ActiveRepositoryData
 from dagster.core.storage.compute_log_manager import ComputeIOType
 
 from .format_error import format_error_with_stack_trace
@@ -56,9 +57,7 @@ class DagsterGraphQLView(GraphQLView):
 
 
 def dagster_graphql_subscription_view(subscription_server, context):
-    context = check.inst_param(
-        context, 'context', (DagsterGraphQLContext, DagsterSnapshotGraphQLContext)
-    )
+    context = check.inst_param(context, 'context', DagsterGraphQLContext)
 
     def view(ws):
         subscription_server.handle(ws, request_context=context)
@@ -110,9 +109,7 @@ def notebook_view(request_args):
 
 
 def download_view(context):
-    context = check.inst_param(
-        context, 'context', (DagsterGraphQLContext, DagsterSnapshotGraphQLContext)
-    )
+    context = check.inst_param(context, 'context', DagsterGraphQLContext)
 
     def view(run_id, step_key, file_type):
         run_id = str(uuid.UUID(run_id))  # raises if not valid run_id
@@ -196,16 +193,16 @@ def get_execution_manager(instance):
     return SubprocessExecutionManager(instance)
 
 
-def create_app_with_snapshot(repository_snapshot, instance):
-    check.inst_param(repository_snapshot, 'snapshot', RepositorySnapshot)
+def create_app_with_active_repository_data(active_repository_data, instance):
+    check.inst_param(active_repository_data, 'active_repository_data', ActiveRepositoryData)
     check.inst_param(instance, 'instance', DagsterInstance)
 
     execution_manager = get_execution_manager(instance)
     warn_if_compute_logs_disabled()
 
     print('Loading repository...')
-    context = DagsterSnapshotGraphQLContext(
-        repository_snapshot=repository_snapshot,
+    context = DagsterGraphQLOutOfProcessRepositoryContext(
+        active_repository_data=active_repository_data,
         instance=instance,
         execution_manager=execution_manager,
         version=__version__,
@@ -222,7 +219,7 @@ def create_app_with_execution_handle(handle, instance, reloader=None):
     warn_if_compute_logs_disabled()
 
     print('Loading repository...')
-    context = DagsterGraphQLContext(
+    context = DagsterGraphQLInProcessRepositoryContext(
         handle=handle,
         instance=instance,
         execution_manager=execution_manager,
